@@ -1,24 +1,23 @@
 import hashlib
 import json
 
-from autocert import utils
+from autocert.rfc4648 import base64url
 
 
 class JWK(dict):
 
-    @classmethod
-    def from_public_key(cls, public_key):
+    def __init__(self, public_key):
         jwk = {
             'kty': 'EC',
             'crv': public_key.curve,
-            'x': utils.base64_rfc4648(public_key.x),
-            'y': utils.base64_rfc4648(public_key.y),
+            'x': base64url(public_key.x),
+            'y': base64url(public_key.y),
         }
-        return cls(jwk)
+        super().__init__(jwk)
 
     def thumbprint(self):
         thumbprint = json.dumps(self, separators=(',', ':'), sort_keys=True)
         thumbprint = thumbprint.encode()
         thumbprint = hashlib.sha256(thumbprint).digest()
-        thumbprint = utils.base64_rfc4648(thumbprint)
+        thumbprint = base64url(thumbprint)
         return thumbprint
